FileFormats Extras
==================
.. image:: https://github.com/arcanaframework/fileformats/actions/workflows/ci-cd.yml/badge.svg
   :target: https://github.com/arcanaframework/fileformats/actions/workflows/ci-cd.yml
.. image:: https://codecov.io/gh/arcanaframework/fileformats/branch/main/graph/badge.svg?token=UIS0OGPST7
   :target: https://codecov.io/gh/arcanaframework/fileformats
.. image:: https://img.shields.io/pypi/pyversions/fileformats-extras.svg
   :target: https://pypi.python.org/pypi/fileformats-extras/
   :alt: Supported Python versions
.. image:: https://img.shields.io/pypi/v/fileformats-extras.svg
   :target: https://pypi.python.org/pypi/fileformats-extras/
   :alt: Latest Version
.. image:: https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat
    :target: https://arcanaframework.github.io/fileformats/
    :alt: Documentation Status


This is a extras module for the
`fileformats <https://github.com/ArcanaFramework/fileformats>`__ package, which provides
additional functionality to format classes (i.e. aside from basic identification and validation), such as
conversion tools, metadata parsers, test data generators, etc...


Quick Installation
------------------

This extension can be installed for Python 3 using *pip*::

    $ pip3 install fileformats-extras

This will install the core package and any other dependencies

License
-------

This work is licensed under a
`Creative Commons Attribution 4.0 International License <http://creativecommons.org/licenses/by/4.0/>`_

.. image:: https://i.creativecommons.org/l/by/4.0/88x31.png
  :target: http://creativecommons.org/licenses/by/4.0/
  :alt: Creative Commons Attribution 4.0 International License
